Plasmid assessor
================

Plasmid assessment for Golden Gate cloning


**Install:**

.. code:: bash

    pip install plasmid_assessor


**Web documentation:** `<https://edinburgh-genome-foundry.github.io/Plasmid_assessor/>`_


**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/Plasmid_assessor>`_


**License:** MIT

Copyright 2021 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Plasmid assessor is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
